@@ -1,6 +1,6 @@
 
 /*
- *  agInit.c  $Id: agInit.c,v 4.6 2005/12/05 20:51:36 bkorb Exp $
+ *  agInit.c  $Id: agInit.c,v 4.8 2006/09/24 02:11:15 bkorb Exp $
  *
  *  Time-stamp:      "2005-12-04 19:42:46 bkorb"
  *
@@ -9,7 +9,7 @@
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -36,7 +36,7 @@ addSysEnv( char* pzEnvName );
 
 #ifdef DAEMON_ENABLED
  static ag_bool evalProto( tCC** ppzS, uint16_t* pProto );
- static void spawnPipe( const char* pzFile );
+ static void spawnPipe( char const* pzFile );
  static void spawnListens( tCC* pzPort, sa_family_t af );
  static void becomeDaemon( tCC*, tCC*, tCC*, tCC* );
 #endif
@@ -638,7 +638,6 @@ becomeDaemon( tCC* pzStdin,
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/agInit.c */
