@@ -1,12 +1,16 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 4.7 2006/01/28 21:26:40 bkorb Exp $
+ *  $Id: agUtils.c,v 4.12 2006/09/24 02:58:59 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:56:07 bkorb"
+ *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *
  *  This is the main routine for autogen.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -61,7 +65,7 @@ strlcpy( char* dest, tCC* src, size_t n )
 
 
 LOCAL char*
-aprf( const char* pzFmt, ... )
+aprf( char const* pzFmt, ... )
 {
     char* pz;
     va_list ap;
@@ -81,6 +85,35 @@ aprf( const char* pzFmt, ... )
 }
 
 
+LOCAL char*
+mkstempPat( void )
+{
+    static char const * pzTmpDir = NULL;
+
+    if (pzTmpDir == NULL) {
+        static char const * const envlist[] = {
+            "TMPDIR", "TEMP", "TMP", NULL };
+        char const * const * penv = envlist;
+        for (;;) {
+            pzTmpDir = getenv(*penv);
+            if (pzTmpDir != NULL)
+                break;
+            if (*(++penv) == NULL) {
+                pzTmpDir = "/tmp";
+                break;
+            }
+        }
+    }
+
+    {
+        char* pzRes = aprf("%s/agtmp.XXXXXX", pzTmpDir);
+        manageAllocatedData((void*)pzRes);
+        TAGMEM( pzRes, "temp file template" );
+        return pzRes;
+    }
+}
+
+
 LOCAL void
 doOptions( int arg_ct, char** arg_vec )
 {
@@ -116,7 +149,7 @@ doOptions( int arg_ct, char** arg_vec )
     }
 
     if (! HAVE_OPT( TIMEOUT ))
-        OPT_VALUE_TIMEOUT = AG_DEFAULT_TIMEOUT;
+        OPT_ARG(TIMEOUT) = (char const *)AG_DEFAULT_TIMEOUT;
 
     /*
      *  IF the definitions file has been disabled,
@@ -375,7 +408,6 @@ skipExpression( tCC* pzSrc, size_t len )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/agUtils.c */
