@@ -1,7 +1,7 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (cgi-fsm.c)
  *  
- *  It has been AutoGen-ed  Saturday August 12, 2006 at 10:37:38 AM PDT
+ *  It has been AutoGen-ed  Saturday September 30, 2006 at 12:32:50 PM PDT
  *  From the definitions    cgi.def
  *  and the template file   fsm
  *
@@ -122,7 +122,7 @@ cgi_trans_table[ CGI_STATE_CT ][ CGI_EVENT_CT ] = {
 #define CgiStInit_off     83
 
 
-static const char zCgiStrings[133] =
+static char const zCgiStrings[133] =
     "** OUT-OF-RANGE **\0"
     "FSM Error:  in state %d (%s), event %d (%s) is invalid\n\0"
     "invalid\0"
@@ -179,7 +179,7 @@ cgi_invalid_transition( te_cgi_state st, te_cgi_event evt )
  */
 te_cgi_state
 cgi_run_fsm(
-    const char* pzSrc,
+    char const* pzSrc,
     int inlen,
     char* pzOut,
     int outlen )
@@ -324,7 +324,6 @@ cgi_run_fsm(
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of cgi-fsm.c */
