@@ -1,6 +1,10 @@
 /*
  *  defDirect.c
- *  $Id: defDirect.c,v 4.8 2006/07/22 04:50:19 bkorb Exp $
+ *  $Id: defDirect.c,v 4.11 2006/09/24 02:58:59 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:55:08 bkorb"
+ *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *
  *  This module processes definition file directives.
  *
  *  blocksort spacing=2 \
@@ -418,9 +422,9 @@ doDir_IGNORE( char* pzArg, char* pzScan )
  *  or "false").
 =*/
 static void
-check_assert_str( const char* pz, const char* pzArg )
+check_assert_str( char const* pz, char const* pzArg )
 {
-    static const char fmt[] = "#assert yielded \"%s\":\n\t`%s`";
+    static char const fmt[] = "#assert yielded \"%s\":\n\t`%s`";
 
     while (isspace(*pz)) pz++;
 
@@ -448,7 +452,7 @@ doDir_assert( char* pzArg, char* pzScan )
             break; /* not a valid script */
 
         *pzR = NUL;
-        pzS = runShell( (const char*)pzS );
+        pzS = runShell( (char const*)pzS );
         check_assert_str( pzS, pzArg );
         free(pzS);
         break;
@@ -1037,7 +1041,6 @@ doDir_undef( char* pzArg, char* pzScan )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/defDirect.c */
