@@ -1,7 +1,7 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (defParse-fsm.c)
  *  
- *  It has been AutoGen-ed  Saturday August 12, 2006 at 10:37:39 AM PDT
+ *  It has been AutoGen-ed  Saturday September 30, 2006 at 12:32:52 PM PDT
  *  From the definitions    defParse.def
  *  and the template file   fsm
  *
@@ -298,7 +298,7 @@ dp_trans_table[ DP_STATE_CT ][ DP_EVENT_CT ] = {
 #define DpStInit_off     83
 
 
-static const char zDpStrings[279] =
+static char const zDpStrings[279] =
     "** OUT-OF-RANGE **\0"
     "FSM Error:  in state %d (%s), event %d (%s) is invalid\n\0"
     "invalid\0"
@@ -631,7 +631,6 @@ dp_run_fsm( void )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of defParse-fsm.c */
