@@ -1,7 +1,10 @@
-/*  -*- Mode: C -*-
- *
+/*
  *  expFormat.c
- *  $Id: expFormat.c,v 4.15 2006/06/24 23:36:07 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:53:35 bkorb"
+ *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *
+ *  $Id: expFormat.c,v 4.18 2006/09/24 02:58:59 bkorb Exp $
  *  This module implements formatting expression functions.
  */
 
@@ -25,7 +28,7 @@
  *             Boston, MA  02110-1301, USA.
  */
 
-static const char zGpl[] =
+static char const zGpl[] =
 "%2$s%1$s is free software.\n%2$s\n"
 "%2$sYou may redistribute it and/or modify it under the terms of the\n"
 "%2$sGNU General Public License, as published by the Free Software\n"
@@ -43,7 +46,7 @@ static const char zGpl[] =
 "%2$s\t51 Franklin Street, Fifth Floor\n"
 "%2$s\tBoston, MA  02110-1301, USA.";
 
-static const char zLgpl[] =
+static char const zLgpl[] =
 "%2$s%1$s is free software; you can redistribute it and/or\n"
 "%2$smodify it under the terms of the GNU Lesser General Public\n"
 "%2$sLicense as published by the Free Software Foundation; either\n"
@@ -60,7 +63,7 @@ static const char zLgpl[] =
 "%2$s\t51 Franklin Street, Fifth Floor\n"
 "%2$s\tBoston, MA  02110-1301, USA.";
 
-static const char zBsd[] =
+static char const zBsd[] =
 "%2$s%1$s is free software copyrighted by %3$s.\n%2$s\n"
 "%2$sRedistribution and use in source and binary forms, with or without\n"
 "%2$smodification, are permitted provided that the following conditions\n"
@@ -86,18 +89,18 @@ static const char zBsd[] =
 "%2$sOTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF\n"
 "%2$sADVISED OF THE POSSIBILITY OF SUCH DAMAGE.";
 
-static const char zDne1[] =
+static char const zDne1[] =
 "%s -*- buffer-read-only: t -*- vi: set ro:\n"
 "%s\n";
 
-static const char zDne[] = "%6$s"
+static char const zDne[] = "%6$s"
 "%1$sDO NOT EDIT THIS FILE   (%2$s)\n"
 "%1$s\n"
 "%1$sIt has been AutoGen-ed  %3$s\n"
 "%1$sFrom the definitions    %4$s\n"
 "%1$sand the template file   %5$s";
 
-static const char zDne2[] = "%6$s"
+static char const zDne2[] = "%6$s"
 "%1$sEDIT THIS FILE WITH CAUTION  (%2$s)\n"
 "%1$s\n"
 "%1$sIt has been AutoGen-ed  %3$s\n"
@@ -183,7 +186,7 @@ ag_scm_dne( SCM prefix, SCM first, SCM opt )
     }
 
     {
-        const char* pz;
+        char const* pz;
         if (! ENABLED_OPT( DEFINITIONS ))
             pz = "<<no definitions>>";
 
@@ -623,7 +626,6 @@ ag_scm_license( SCM license, SCM prog_name, SCM owner, SCM prefix )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/expFormat.c */
