@@ -2,7 +2,7 @@
  * Copyright (c) 2004-2006
  *  Bruce Korb.  All rights reserved.
  *
- * Time-stamp:      "2006-01-24 14:47:47 bkorb"
+ * Time-stamp:      "2006-07-15 08:28:08 bkorb"
  *
  * This code was inspired from software written by
  *   Hanno Mueller, kontakt@hanno.de
@@ -76,12 +76,13 @@
    typedef fpos_t  seek_pos_t;
 
    typedef int     (cookie_read_function_t )(void *, char *, int);
-   typedef int     (cookie_write_function_t)(void *, const char *, int);
+   typedef int     (cookie_write_function_t)(void *, char const *, int);
    typedef fpos_t  (cookie_seek_function_t )(void *, fpos_t, int);
    typedef int     (cookie_close_function_t)(void *);
 
 #else
 #  error  OOPS
+   Choke Me.
 #endif
 
 #define PROP_TABLE \
@@ -122,7 +123,7 @@ struct fmem_cookie_s {
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by :mkfwd */
 static int
-fmem_getmode( const char *pMode, mode_bits_t *pRes );
+fmem_getmode( char const *pMode, mode_bits_t *pRes );
 
 static int
 fmem_extend( fmem_cookie_t *pFMC, size_t new_size );
@@ -140,12 +141,15 @@ static int
 fmem_close( void *cookie );
 /* = = = END-STATIC-FORWARD = = = */
 
+FILE * ag_fmemopen(void *buf, ssize_t len, char const *pMode);
+int fmem_ioctl( FILE* fp, int req, void* ptr );
+
 #ifdef TEST_FMEMOPEN
   static fmem_cookie_t* saved_cookie = NULL;
 #endif
 
 static int
-fmem_getmode( const char *pMode, mode_bits_t *pRes )
+fmem_getmode( char const *pMode, mode_bits_t *pRes )
 {
     if (pMode == NULL)
         return 1;
@@ -313,7 +317,7 @@ fmem_write( void *cookie, const void *pBuf, size_t sz )
 static seek_pos_t
 fmem_seek( void *cookie, fmem_off_t *p_offset, int dir)
 {
-    fmem_off_t new_pos;
+    size_t new_pos;
     fmem_cookie_t *pFMC = cookie;
 
     switch (dir) {
@@ -482,7 +486,7 @@ fmem_ioctl( FILE* fp, int req, void* ptr )
  *  Any other letters following the inital 'a', 'w' or 'r' will cause an error.
 =*/
 FILE *
-ag_fmemopen(void *buf, ssize_t len, const char *pMode)
+ag_fmemopen(void *buf, ssize_t len, char const *pMode)
 {
     fmem_cookie_t *pFMC;
 
@@ -585,7 +589,7 @@ ag_fmemopen(void *buf, ssize_t len, const char *pMode)
         /*
          *  Unallocated file space is set to NULs.  Emulate that.
          */
-        pFMC->buffer = calloc(1, len);
+        pFMC->buffer = calloc(1, (unsigned)len);
         if (pFMC->buffer == NULL) {
             errno = ENOMEM;
             free( pFMC );
@@ -634,7 +638,6 @@ ag_fmemopen(void *buf, ssize_t len, const char *pMode)
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/fmemopen.c */
