@@ -1,6 +1,9 @@
 
 /*
- *  $Id: funcDef.c,v 4.13 2006/07/22 04:50:19 bkorb Exp $
+ *  $Id: funcDef.c,v 4.16 2006/09/24 02:59:00 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:51:46 bkorb"
+ *  Last Committed:    $Date: 2006/09/24 02:59:00 $
  *
  *  This module implements the DEFINE text function.
  */
@@ -447,7 +450,7 @@ build_defs( int defCt, tDefList* pList )
                 AGDUPSTR( pList->de.val.pzText, ag_scm2zchars(res, "eval res"),
                           "dup eval res" );
             }
-            else if (AG_SCM_NUMBER_P( res )) {
+            else if (AG_SCM_NUM_P( res )) {
                 pList->de.val.pzText = AGALOC( 16, "number buf" );
                 snprintf( pList->de.val.pzText, 16, "%ld", gh_scm2ulong( res ));
             }
@@ -728,8 +731,8 @@ mLoad_Define( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     papLoadProc = apDefineLoad;
 
     {
-        const char*    pzScan = *ppzScan;  /* text after macro */
-        const char*    pzSrc  = (const char*)pMac->ozText; /* macro text */
+        char const*    pzScan = *ppzScan;  /* text after macro */
+        char const*    pzSrc  = (char const*)pMac->ozText; /* macro text */
         int            macCt  = pT->macroCt - (pMac - pT->aMacros);
 
         size_t alocSize = sizeof( *pNewT )
@@ -834,7 +837,6 @@ mLoad_Define( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/funcDef.c */
