@@ -1,6 +1,9 @@
 
 /*
- *  $Id: functions.c,v 4.7 2006/06/24 23:36:07 bkorb Exp $
+ *  $Id: functions.c,v 4.10 2006/09/24 02:59:00 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:51:33 bkorb"
+ *  Last Committed:    $Date: 2006/09/24 02:59:00 $
  *
  *  This module implements text functions.
  */
@@ -246,13 +249,13 @@ tMacro*
 mLoad_Unknown( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
     char*          pzCopy = pT->pNext;
-    const char*    pzSrc;
+    char const*    pzSrc;
     size_t         srcLen = (size_t)pMac->res;         /* macro len  */
 
     if (srcLen <= 0)
         goto return_emtpy_expression;
 
-    pzSrc = (const char*)pMac->ozText; /* macro text */
+    pzSrc = (char const*)pMac->ozText; /* macro text */
 
     switch (*pzSrc) {
     case ';':
@@ -348,7 +351,7 @@ mLoad_Bogus( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     tSCC zUnk[] =
         "Unknown macro or invalid context in %s line %d:\n\t%s%s";
 
-    tCC* pzSrc = (const char*)pMac->ozText; /* macro text */
+    tCC* pzSrc = (char const*)pMac->ozText; /* macro text */
     tCC* pzMac;
 
     char z[ 64 ];
@@ -381,7 +384,6 @@ mLoad_Bogus( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/functions.c */
