@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sat Aug 12 10:37:39 PDT 2006
+ * Generated Sat Sep 30 12:32:53 PDT 2006
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -41,13 +41,13 @@ LOCAL pid_t
 openServerFP( tpfPair* pfPair, tCC** ppArgs );
 
 LOCAL char*
-runShell( const char*  pzCmd );
+runShell( char const*  pzCmd );
 
 /*
  *  Extracted from agUtils.c
  */
 LOCAL char*
-aprf( const char* pzFmt, ... );
+aprf( char const* pzFmt, ... );
 
 LOCAL char*
 mkstempPat( void );
@@ -77,6 +77,18 @@ ag_abend_at( tCC* pzMsg
 #endif
     );
 
+LOCAL void *
+ao_malloc (size_t sz);
+
+LOCAL void *
+ao_realloc (void *p, size_t sz);
+
+LOCAL void
+ao_free (void *p);
+
+LOCAL char *
+ao_strdup (char const * str);
+
 /*
  *  Extracted from defDirect.c
  */
@@ -87,7 +99,7 @@ processDirective( char* pzScan );
  *  Extracted from defFind.c
  */
 LOCAL int
-canonicalizeName( char* pzD, const char* pzS, int srcLen );
+canonicalizeName( char* pzD, char const* pzS, int srcLen );
 
 LOCAL tDefEntry*
 findDefEntry( char* pzName, ag_bool* pIsIndexed );
@@ -159,7 +171,7 @@ LOCAL tCC*
 evalExpression( ag_bool* pMustFree );
 
 LOCAL SCM
-eval( const char* pzExpr );
+eval( char const* pzExpr );
 
 /*
  *  Extracted from loadPseudo.c
