@@ -1,7 +1,7 @@
 
 /*
- *  $Id: enumeration.c,v 4.9 2006/03/25 19:24:56 bkorb Exp $
- * Time-stamp:      "2005-12-09 06:37:15 bkorb"
+ *  $Id: enumeration.c,v 4.11 2006/09/24 02:11:16 bkorb Exp $
+ * Time-stamp:      "2006-09-22 18:00:53 bkorb"
  *
  *   Automated Options Paged Usage module.
  *
@@ -84,7 +84,7 @@ enumError(
 
     if (pOpts != NULL)
         fprintf( option_usage_fp, pz_enum_err_fmt,
-                 pOpts->pzProgName, pOD->pzLastArg );
+                 pOpts->pzProgName, pOD->optArg.argString );
 
     fprintf( option_usage_fp, zValidKeys, pOD->pz_Name );
 
@@ -193,7 +193,7 @@ findName(
             if (res != name_ct) {
                 pz_enum_err_fmt = zAmbigKey;
                 option_usage_fp = stderr;
-                enumError( pOpts, pOD, paz_names, name_ct );
+                enumError( pOpts, pOD, paz_names, (int)name_ct );
             }
             res = idx; /* save partial match */
         }
@@ -205,7 +205,7 @@ findName(
     if (res == name_ct) {
         pz_enum_err_fmt = zNoKey;
         option_usage_fp = stderr;
-        enumError( pOpts, pOD, paz_names, name_ct );
+        enumError( pOpts, pOD, paz_names, (int)name_ct );
     }
 
     /*
@@ -223,21 +223,21 @@ findName(
  * arg:   tOptDesc*,     pOD,       enumeration option description
  * arg:   unsigned int,  enum_val,  the enumeration value to map
  *
- * ret_type:  const char*
+ * ret_type:  char const*
  * ret_desc:  the enumeration name from const memory
  *
  * doc:   This converts an enumeration value into the matching string.
 =*/
-const char*
+char const*
 optionKeywordName(
     tOptDesc*     pOD,
     unsigned int  enum_val )
 {
     tOptDesc od;
 
-    od.pzLastArg = (const char*)(uintptr_t)enum_val;
+    od.optArg.argIntptr = enum_val;
     (*(pOD->pOptProc))( (void*)(2UL), &od );
-    return od.pzLastArg;
+    return od.optArg.argString;
 }
 
 
@@ -247,19 +247,19 @@ optionKeywordName(
  *
  * arg:   tOptions*,     pOpts,     the program options descriptor
  * arg:   tOptDesc*,     pOD,       enumeration option description
- * arg:   const char**,  paz_names, list of enumeration names
+ * arg:   char const**,  paz_names, list of enumeration names
  * arg:   unsigned int,  name_ct,   number of names in list
  *
- * ret_type:  char*
- * ret_desc:  the enumeration value cast as a char*
+ * ret_type:  uintptr_t
+ * ret_desc:  the enumeration value
  *
- * doc:   This converts the pzLastArg string from the option description
+ * doc:   This converts the optArg.argString string from the option description
  *        into the index corresponding to an entry in the name list.
  *        This will match the generated enumeration value.
  *        Full matches are always accepted.  Partial matches are accepted
  *        if there is only one partial match.
 =*/
-char*
+uintptr_t
 optionEnumerationVal(
     tOptions*     pOpts,
     tOptDesc*     pOD,
@@ -275,12 +275,12 @@ optionEnumerationVal(
         /*
          *  print the list of enumeration names.
          */
-        enumError( pOpts, pOD, paz_names, name_ct );
-        return (char*)0UL;
+        enumError( pOpts, pOD, paz_names, (int)name_ct );
+        return 0UL;
 
     case 1UL:
     {
-        unsigned int ix = (uintptr_t)(pOD->pzLastArg);
+        unsigned int ix = pOD->optArg.argIntptr;
         /*
          *  print the name string.
          */
@@ -288,25 +288,25 @@ optionEnumerationVal(
             printf( "INVALID-%d", ix );
         else
             fputs( paz_names[ ix ], stdout );
-        return (char*)0UL;
+        return 0UL;
     }
     case 2UL:
     {
         tSCC zInval[] = "*INVALID*";
-        unsigned int ix = (uintptr_t)(pOD->pzLastArg);
+        unsigned int ix = pOD->optArg.argIntptr;
         /*
          *  Replace the enumeration value with the name string.
          */
         if (ix >= name_ct)
-            return (char*)zInval;
+            return (uintptr_t)zInval;
 
-        return (char*)paz_names[ ix ];
+        return (uintptr_t)paz_names[ ix ];
     }
     default:
         break;
     }
 
-    return (char*)findName( pOD->pzLastArg, pOpts, pOD, paz_names, name_ct );
+    return findName( pOD->optArg.argString, pOpts, pOD, paz_names, name_ct );
 }
 
 
@@ -316,10 +316,10 @@ optionEnumerationVal(
  *
  * arg:   tOptions*,     pOpts,     the program options descriptor
  * arg:   tOptDesc*,     pOD,       enumeration option description
- * arg:   const char**,  paz_names, list of enumeration names
+ * arg:   char const**,  paz_names, list of enumeration names
  * arg:   unsigned int,  name_ct,   number of names in list
  *
- * doc:   This converts the pzLastArg string from the option description
+ * doc:   This converts the optArg.argString string from the option description
  *        into the index corresponding to an entry in the name list.
  *        This will match the generated enumeration value.
  *        Full matches are always accepted.  Partial matches are accepted
@@ -341,7 +341,7 @@ optionSetMembers(
         /*
          *  print the list of enumeration names.
          */
-        enumError( pOpts, pOD, paz_names, name_ct );
+        enumError( pOpts, pOD, paz_names, (int)name_ct );
         return;
 
     case 1UL:
@@ -382,7 +382,7 @@ optionSetMembers(
             bits >>= 1;
         }
 
-        pOD->pzLastArg = pz = malloc( len );
+        pOD->optArg.argString = pz = malloc( len );
         /*
          *  Start by clearing all the bits.  We want to turn off any defaults
          *  because we will be restoring to current state, not adding to
@@ -409,7 +409,7 @@ optionSetMembers(
     }
 
     {
-        tCC*      pzArg = pOD->pzLastArg;
+        tCC*      pzArg = pOD->optArg.argString;
         uintptr_t res;
         if ((pzArg == NULL) || (*pzArg == NUL)) {
             pOD->optCookie = (void*)0;
@@ -433,7 +433,7 @@ optionSetMembers(
             if ((len == 3) && (strncmp( pzArg, zAll, 3 ) == 0)) {
                 if (iv)
                      res = 0;
-                else res = ~0;
+                else res = ~0UL;
             }
             else if ((len == 4) && (strncmp( pzArg, zNone, 4 ) == 0)) {
                 if (! iv)
@@ -449,7 +449,7 @@ optionSetMembers(
                     if (*pz != NUL) {
                         if (len >= AO_NAME_LIMIT)
                             break;
-                        strncpy( z, pzArg, len );
+                        strncpy( z, pzArg, (unsigned)len );
                         z[len] = NUL;
                         p = z;
                     } else {
@@ -479,7 +479,6 @@ optionSetMembers(
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/enumeration.c */
