@@ -1,6 +1,7 @@
 
 /*
- *  save.c  $Id: save.c,v 4.2 2005/01/01 04:18:03 bkorb Exp $
+ *  save.c  $Id: save.c,v 4.10 2006/09/24 02:11:16 bkorb Exp $
+ * Time-stamp:      "2006-09-22 18:11:20 bkorb"
  *
  *  This module's routines will take the currently set options and
  *  store them into an ".rc" file for re-interpretation the next
@@ -8,7 +9,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2004 Bruce Korb
+ *  Automated Options copyright 1992-2006 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -23,8 +24,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with Automated Options.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  *
  * As a special exception, Bruce Korb gives permission for additional
  * uses of the text contained in his release of AutoOpts.
@@ -52,30 +53,30 @@
 
 tSCC  zWarn[] = "%s WARNING:  cannot save options - ";
 
-/* === STATIC PROCS === */
-STATIC tCC*
-findDirName( tOptions* pOpts );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static tCC*
+findDirName( tOptions* pOpts, int* p_free );
 
-STATIC tCC*
-findFileName( tOptions* pOpts );
+static tCC*
+findFileName( tOptions* pOpts, int* p_free_name );
 
-STATIC void
+static void
 printEntry(
     FILE*      fp,
     tOptDesc*  p,
     tCC*       pzLA );
+/* = = = END-STATIC-FORWARD = = = */
 
-/* === END STATIC PROCS === */
-
-STATIC tCC*
-findDirName( tOptions* pOpts )
+static tCC*
+findDirName( tOptions* pOpts, int* p_free )
 {
     tCC*  pzDir;
 
     if (pOpts->specOptIdx.save_opts == 0)
         return NULL;
 
-    pzDir = pOpts->pOptDesc[ pOpts->specOptIdx.save_opts ].pzLastArg;
+    pzDir = pOpts->pOptDesc[ pOpts->specOptIdx.save_opts ].optArg.argString;
     if ((pzDir != NULL) && (*pzDir != NUL))
         return pzDir;
 
@@ -99,7 +100,7 @@ findDirName( tOptions* pOpts )
         return pzDir;
 
     {
-        tCC*  pzEndDir = strchr( ++pzDir, '/' );
+        tCC*  pzEndDir = strchr( ++pzDir, DIRCH );
         char* pzFileName;
         char* pzEnv;
 
@@ -107,7 +108,7 @@ findDirName( tOptions* pOpts )
             char z[ AO_NAME_SIZE ];
             if ((pzEndDir - pzDir) > AO_NAME_LIMIT )
                 return NULL;
-            strncpy( z, pzDir, (pzEndDir - pzDir) );
+            strncpy( z, pzDir, (unsigned)(pzEndDir - pzDir) );
             z[ (pzEndDir - pzDir) ] = NUL;
             pzEnv = getenv( z );
         } else {
@@ -129,13 +130,14 @@ findDirName( tOptions* pOpts )
             return pzEnv;
 
         {
-            size_t sz = strlen( pzEnv ) + strlen( pzEndDir );
+            size_t sz = strlen( pzEnv ) + strlen( pzEndDir ) + 2;
             pzFileName = (char*)AGALOC( sz, "dir name" );
         }
 
         if (pzFileName == NULL)
             return NULL;
 
+        *p_free = 1;
         /*
          *  Glue together the full name into the allocated memory.
          *  FIXME: We lose track of this memory.
@@ -146,13 +148,14 @@ findDirName( tOptions* pOpts )
 }
 
 
-STATIC tCC*
-findFileName( tOptions* pOpts )
+static tCC*
+findFileName( tOptions* pOpts, int* p_free_name )
 {
     tCC*   pzDir;
     struct stat stBuf;
+    int    free_dir_name = 0;
 
-    pzDir = findDirName( pOpts );
+    pzDir = findDirName( pOpts, &free_dir_name );
     if (pzDir == NULL)
         return NULL;
 
@@ -173,13 +176,13 @@ findFileName( tOptions* pOpts )
              *  Strip off the last component, stat the remaining string and
              *  that string must name a directory
              */
-            char* pzDirCh = strrchr( pzDir, '/' );
+            char* pzDirCh = strrchr( pzDir, DIRCH );
             if (pzDirCh == NULL) {
                 stBuf.st_mode = S_IFREG;
-                break;  /* bail out of error condition */
+                continue;  /* bail out of error condition */
             }
 
-            strncpy( z, pzDir, pzDirCh - pzDir );
+            strncpy( z, pzDir, (unsigned)(pzDirCh - pzDir));
             z[ pzDirCh - pzDir ] = NUL;
 
             if (  (stat( z, &stBuf ) == 0)
@@ -190,7 +193,7 @@ findFileName( tOptions* pOpts )
                  *  mark the full name as a regular file
                  */
                 stBuf.st_mode = S_IFREG;
-                break;  /* bail out of error condition */
+                continue;  /* bail out of error condition */
             }
         }
 
@@ -199,12 +202,14 @@ findFileName( tOptions* pOpts )
          */
         fprintf( stderr, zWarn, pOpts->pzProgName );
         fprintf( stderr, zNoStat, errno, strerror( errno ), pzDir );
+        if (free_dir_name)
+            AGFREE( (void*)pzDir );
         return NULL;
     } while (0);
 
     /*
      *  IF what we found was a directory,
-     *  THEN tack on the RC file name
+     *  THEN tack on the config file name
      */
     if (S_ISDIR( stBuf.st_mode )) {
         size_t sz = strlen( pzDir ) + strlen( pOpts->pzRcName ) + 2;
@@ -216,7 +221,10 @@ findFileName( tOptions* pOpts )
 #else
             sprintf( pzPath, "%s/%s", pzDir, pOpts->pzRcName );
 #endif
+            if (free_dir_name)
+                AGFREE( (void*)pzDir );
             pzDir = pzPath;
+            free_dir_name = 1;
         }
 
         /*
@@ -228,6 +236,7 @@ findFileName( tOptions* pOpts )
                 fprintf( stderr, zWarn, pOpts->pzProgName );
                 fprintf( stderr, zNoStat, errno, strerror( errno ),
                          pzDir );
+                AGFREE( (void*)pzDir );
                 return NULL;
             }
 
@@ -245,6 +254,8 @@ findFileName( tOptions* pOpts )
     if (! S_ISREG( stBuf.st_mode )) {
         fprintf( stderr, zWarn, pOpts->pzProgName );
         fprintf( stderr, zNotFile, pzDir );
+        if (free_dir_name)
+            AGFREE( (void*)pzDir );
         return NULL;
     }
 
@@ -252,11 +263,12 @@ findFileName( tOptions* pOpts )
      *  Get rid of the old file
      */
     unlink( pzDir );
+    *p_free_name = free_dir_name;
     return pzDir;
 }
 
 
-STATIC void
+static void
 printEntry(
     FILE*      fp,
     tOptDesc*  p,
@@ -272,7 +284,7 @@ printEntry(
      *  IF the option is numeric only,
      *  THEN the char pointer is really the number
      */
-    if ((p->fOptState & OPTST_NUMERIC) != 0)
+    if (OPTST_GET_ARGTYPE(p->fOptState) == OPARG_TYPE_NUMERIC)
         fprintf( fp, "  %d\n", (t_word)pzLA );
 
     /*
@@ -296,7 +308,7 @@ printEntry(
             /*
              *  Print the continuation and the text from the current line
              */
-            fwrite( pzLA, pzNl - pzLA, 1, fp );
+            (void)fwrite( pzLA, (unsigned)(pzNl - pzLA), 1, fp );
             pzLA = pzNl+1; /* advance the Last Arg pointer */
             fputs( "\\\n", fp );
         }
@@ -331,98 +343,105 @@ printEntry(
  * and do nothing.  If the output file cannot be created or updated, a message
  * will be printed to @code{stderr} and the routine will return.
 =*/
-#define ARGTYPE (OPTST_NUMERIC \
-  | OPTST_STACKED | OPTST_ENUMERATION | OPTST_MEMBER_BITS | OPTST_BOOLEAN )
-
 void
 optionSaveFile( tOptions* pOpts )
 {
-    tCC*  pzFName;
-
-    pzFName = findFileName( pOpts );
-    if (pzFName == NULL)
-        return;
+    tOptDesc* pOD;
+    int       ct;
+    FILE*     fp;
 
     {
-        tOptDesc* pOD = pOpts->pOptDesc;
-        int       ct  = pOpts->presetOptCt;
-        FILE*     fp  = fopen( pzFName, "w" FOPEN_BINARY_FLAG );
+        int   free_name = 0;
+        tCC*  pzFName = findFileName( pOpts, &free_name );
+        if (pzFName == NULL)
+            return;
 
+        fp = fopen( pzFName, "w" FOPEN_BINARY_FLAG );
         if (fp == NULL) {
             fprintf( stderr, zWarn, pOpts->pzProgName );
             fprintf( stderr, zNoCreat, errno, strerror( errno ), pzFName );
+            if (free_name)
+                AGFREE((void*) pzFName );
             return;
         }
 
-        {
-            const char*  pz = pOpts->pzUsageTitle;
-            fputs( "#  ", fp );
-            do { fputc( *pz, fp ); } while (*(pz++) != '\n');
-        }
+        if (free_name)
+            AGFREE( (void*)pzFName );
+    }
 
-        {
-            time_t  timeVal = time( NULL );
-            char*   pzTime  = ctime( &timeVal );
+    {
+        char const*  pz = pOpts->pzUsageTitle;
+        fputs( "#  ", fp );
+        do { fputc( *pz, fp ); } while (*(pz++) != '\n');
+    }
 
-            fprintf( fp, zPresetFile, pzTime );
+    {
+        time_t  timeVal = time( NULL );
+        char*   pzTime  = ctime( &timeVal );
+
+        fprintf( fp, zPresetFile, pzTime );
 #ifdef HAVE_ALLOCATED_CTIME
-            /*
-             *  The return values for ctime(), localtime(), and gmtime()
-             *  normally point to static data that is overwritten by each call.
-             *  The test to detect allocated ctime, so we leak the memory.
-             */
-            free( pzTime );
+        /*
+         *  The return values for ctime(), localtime(), and gmtime()
+         *  normally point to static data that is overwritten by each call.
+         *  The test to detect allocated ctime, so we leak the memory.
+         */
+        AGFREE( (void*)pzTime );
 #endif
-        }
+    }
+
+    /*
+     *  FOR each of the defined options, ...
+     */
+    ct  = pOpts->presetOptCt;
+    pOD = pOpts->pOptDesc;
+    do  {
+        int arg_state;
+        tOptDesc*  p;
 
         /*
-         *  FOR each of the defined options, ...
+         *  IF    the option has not been defined
+         *     OR it does not take an initialization value
+         *     OR it is equivalenced to another option
+         *  THEN continue (ignore it)
          */
-        do  {
-            tOptDesc*  p;
+        if (UNUSED_OPT( pOD ))
+            continue;
 
-            /*
-             *  IF    the option has not been defined
-             *     OR it does not take an initialization value
-             *     OR it is equivalenced to another option
-             *  THEN continue (ignore it)
-             */
-            if (UNUSED_OPT( pOD ))
-                continue;
+        if ((pOD->fOptState & (OPTST_NO_INIT|OPTST_DOCUMENT|OPTST_OMITTED))
+            != 0)
+            continue;
 
-            if ((pOD->fOptState & (OPTST_NO_INIT|OPTST_DOCUMENT|OPTST_OMITTED))
-                 != 0)
-                continue;
+        if (  (pOD->optEquivIndex != NO_EQUIVALENT)
+              && (pOD->optEquivIndex != pOD->optIndex))
+            continue;
 
-            if (  (pOD->optEquivIndex != NO_EQUIVALENT)
-               && (pOD->optEquivIndex != pOD->optIndex))
-                continue;
+        /*
+         *  Set a temporary pointer to the real option description
+         *  (i.e. account for equivalencing)
+         */
+        p = ((pOD->fOptState & OPTST_EQUIVALENCE) != 0)
+            ? (pOpts->pOptDesc + pOD->optActualIndex) : pOD;
 
-            /*
-             *  Set a temporary pointer to the real option description
-             *  (i.e. account for equivalencing)
-             */
-            p = ((pOD->fOptState & OPTST_EQUIVALENCE) != 0)
-                ? (pOpts->pOptDesc + pOD->optActualIndex) : pOD;
+        /*
+         *  IF    no arguments are allowed
+         *  THEN just print the name and continue
+         */
+        if (OPTST_GET_ARGTYPE(pOD->fOptState) == OPARG_TYPE_NONE) {
+            fprintf( fp, "%s\n",
+                     (DISABLED_OPT( p )) ? p->pz_DisableName : p->pz_Name );
+            continue;
+        }
 
-            /*
-             *  IF    no arguments are allowed
-             *  THEN just print the name and continue
-             */
-            if (p->optArgType == ARG_NONE) {
-                fprintf( fp, "%s\n",
-                         (DISABLED_OPT( p )) ? p->pz_DisableName : p->pz_Name );
-                continue;
-            }
+        arg_state = OPTST_GET_ARGTYPE(p->fOptState);
+        switch (arg_state) {
+        case 0:
+        case OPARG_TYPE_NUMERIC:
+            printEntry( fp, p, p->optArg.argString );
+            break;
 
-            switch (p->fOptState & ARGTYPE) {
-            case 0:
-            case OPTST_NUMERIC:
-                printEntry( fp, p, p->pzLastArg );
-                break;
-
-            case OPTST_STACKED:
-            {
+        case OPARG_TYPE_STRING:
+            if (p->fOptState & OPTST_STACKED) {
                 tArgList*  pAL = (tArgList*)p->optCookie;
                 int        uct = pAL->useCt;
                 tCC**      ppz = pAL->apzArgs;
@@ -435,45 +454,47 @@ optionSaveFile( tOptions* pOpts )
 
                 while (uct-- > 0)
                     printEntry( fp, p, *(ppz++) );
-                break;
+            } else {
+                printEntry( fp, p, p->optArg.argString );
             }
+            break;
 
-            case OPTST_ENUMERATION:
-            case OPTST_MEMBER_BITS:
-            {
-                tCC* val = p->pzLastArg;
+        case OPARG_TYPE_ENUMERATION:
+        case OPARG_TYPE_MEMBERSHIP:
+        {
+            tCC* val = p->optArg.argString;
+            /*
+             *  This is a magic incantation that will convert the
+             *  bit flag values back into a string suitable for printing.
+             */
+            (*(p->pOptProc))( (tOptions*)2UL, p );
+            printEntry( fp, p, p->optArg.argString );
+            if (  (p->optArg.argString != NULL)
+               && (arg_state != OPARG_TYPE_ENUMERATION))
                 /*
-                 *  This is a magic incantation that will convert the
-                 *  bit flag values back into a string suitable for printing.
+                 *  bit flag and enumeration strings get allocated
                  */
-                (*(p->pOptProc))( (tOptions*)2UL, p );
-                printEntry( fp, p, p->pzLastArg );
-                if (p->pzLastArg != NULL)
-                    /*
-                     *  bit flag strings get allocated
-                     */
-                    free( (char*)p->pzLastArg );
-                p->pzLastArg = val;
-                break;
-            }
+                AGFREE( (void*)p->optArg.argString );
+            p->optArg.argString = val;
+            break;
+        }
 
-            case OPTST_BOOLEAN:
-                printEntry( fp, p, (p->pzLastArg != 0) ? "true" : "false" );
-                break;
+        case OPARG_TYPE_BOOLEAN:
+            printEntry( fp, p, (p->optArg.argBool != AG_FALSE)
+                        ? "true" : "false" );
+            break;
 
-            default:
-                break; /* bogus - skip it */
-            }
-        } while ( (pOD++), (--ct > 0));
+        default:
+            break; /* cannot handle - skip it */
+        }
+    } while ( (pOD++), (--ct > 0));
 
-        fclose( fp );
-    }
+    fclose( fp );
 }
 /*
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/save.c */
