@@ -1,7 +1,7 @@
 
 /*
  *  columns.c
- *  $Id: columns.c,v 4.6 2006/06/24 23:36:08 bkorb Exp $
+ *  $Id: columns.c,v 4.8 2006/09/24 02:11:16 bkorb Exp $
  */
 
 /*
@@ -605,15 +605,14 @@ writeRows( void )
 static int
 compProc( const void* p1, const void* p2 )
 {
-    const char* pz1 = *(char* const*)p1;
-    const char* pz2 = *(char* const*)p2;
+    char const* pz1 = *(char* const*)p1;
+    char const* pz2 = *(char* const*)p2;
     return strcmp( pz1, pz2 );
 }
 /*
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of columns/columns.c */
