@@ -1,7 +1,7 @@
 
 /*
  *  xml2ag.c
- *  $Id: xml2ag.c,v 4.7 2006/03/25 19:25:19 bkorb Exp $
+ *  $Id: xml2ag.c,v 4.8 2006/09/24 02:11:16 bkorb Exp $
  *  This is the main routine for xml2ag.
  *
  *  xml2ag copyright 2002-2006 Bruce Korb
@@ -68,7 +68,7 @@ static void
 emitIndentation( void );
 
 static char*
-trim( const char* pzSrc, size_t* pSz );
+trim( char const* pzSrc, size_t* pSz );
 
 static xmlNodePtr
 printHeader( xmlDocPtr pDoc );
@@ -82,16 +82,16 @@ printNode( xmlNodePtr pNode );
 static void
 printChildren( xmlNodePtr pNode );
 /* = = = END-STATIC-FORWARD = = = */
-#define TRIM(s,psz) trim( (const char*)(s), (size_t*)(psz) )
+#define TRIM(s,psz) trim( (char const*)(s), (size_t*)(psz) )
 
-extern void forkAutogen( const char* pzInput );
+extern void forkAutogen( char const* pzInput );
 
 
 int
 main( int argc, char** argv )
 {
     xmlDocPtr   pDoc;
-    const char* pzFile = NULL;
+    char const* pzFile = NULL;
 
     {
         int ct = optionProcess( &xml2agOptions, argc, argv );
@@ -133,12 +133,12 @@ main( int argc, char** argv )
     else {
         size_t sz;
         char*  pz = loadFile( stdin, &sz );
-        pDoc = xmlParseMemory( pz, sz );
+        pDoc = xmlParseMemory( pz, (int)sz );
         fprintf( outFp, "/* Parsed from stdin */\n" );
     }
 
     {
-        static const char z_not_doc[] =
+        static char const z_not_doc[] =
             "/* type %d doc is not DOCUMENT or HTML_DOCUMENT */\n";
 
         xmlNodePtr pRoot = printHeader( pDoc );
@@ -199,7 +199,7 @@ emitIndentation( void )
 
 
 static char*
-trim( const char* pzSrc, size_t* pSz )
+trim( char const* pzSrc, size_t* pSz )
 {
     static char   zNil[1] = "";
     static char*  pzData  = NULL;
@@ -217,7 +217,7 @@ trim( const char* pzSrc, size_t* pSz )
     while (isspace( *pzSrc ))  pzSrc++;
 
     {
-        const char* pzEnd = pzSrc + strlen( pzSrc );
+        char const* pzEnd = pzSrc + strlen( pzSrc );
         while ((pzEnd > pzSrc) && isspace( pzEnd[-1] ))  pzEnd--;
 
         if (pzEnd <= pzSrc) {
@@ -232,7 +232,7 @@ trim( const char* pzSrc, size_t* pSz )
      *  big enough to hold the newly formed string.
      */
     {
-        const char* pz = pzSrc;
+        char const* pz = pzSrc;
         for (;;) {
             pz += strcspn( pz, "'\\" );
             if (*(pz++) == NUL)
@@ -242,7 +242,7 @@ trim( const char* pzSrc, size_t* pSz )
     }
 
     if (dataLen <= strSize) {
-        size_t sz = (strSize + 0x1000) & ~0x0FFF;
+        size_t sz = (strSize + 0x1000) & ~0x0FFFUL;
         if (pzData == NULL)
              pzData = malloc( sz );
         else pzData = realloc( pzData, sz );
@@ -281,7 +281,7 @@ static xmlNodePtr
 printHeader( xmlDocPtr pDoc )
 {
     tSCC zDef[] = "AutoGen Definitions %s%s;\n";
-    const char* pzSfx = ".tpl";
+    char const* pzSfx = ".tpl";
 
     xmlNodePtr pRootNode = xmlDocGetRootElement( pDoc );
     xmlChar*   pTpl = NULL;
@@ -421,7 +421,7 @@ printNode( xmlNodePtr pNode )
             char* pz = strstr( pzTxt, "*/" );
             if (pz == NULL)
                 break;
-            fwrite( pzTxt, (pz - pzTxt) + 1, 1, outFp );
+            fwrite( pzTxt, (unsigned)((pz - pzTxt) + 1), 1, outFp );
             pzTxt = pz+1;
             fputc( ' ', outFp );
         }
@@ -472,7 +472,6 @@ printChildren( xmlNodePtr pNode )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of xml2ag/xml2ag.c */
